# yzy

各种工具



## Support

- **arxiv.py**: combined
- **id2md.py**: input arxiv id and then get the markdown format output.
- **file2md.py**: input foldername containing papers and then get the markdown format output.

```
python -m yzy.id2md

python yzy.arxiv.id2md()
```







